@@ -235,13 +235,17 @@ class fillVars(object, cl_base.glob_attr):
         if not replServers:
             return ""
         replServers = replServers.split(",")
+        replMailServers = self.Get("ld_repl_mail_servers")
+        if replMailServers:
+            replMailServers = replMailServers.split(",")
         replSambaServers = self.Get("ld_repl_samba_servers")
         if replSambaServers:
             replSambaServers = replSambaServers.split(",")
         replUnixServers = self.Get("ld_repl_unix_servers")
         if replUnixServers:
             replUnixServers = replUnixServers.split(",")
-        if set(replServers) != set(replSambaServers)|set(replUnixServers):
+        if set(replServers) != \
+        set(replSambaServers)|set(replUnixServers)|set(replMailServers):
             return ""
         replIds = self.Get("ld_repl_ids")
         replIds = replIds.split(",")
@@ -290,6 +294,9 @@ class fillVars(object, cl_base.glob_attr):
         if not repl_id:
             return ""
         servers_info = ""
+        replMailServers = self.Get("ld_repl_mail_servers")
+        if replMailServers:
+            replMailServers = replMailServers.split(",")
         replSambaServers = self.Get("ld_repl_samba_servers")
         if replSambaServers:
             replSambaServers = replSambaServers.split(",")
@@ -298,7 +305,8 @@ class fillVars(object, cl_base.glob_attr):
             replUnixServers = replUnixServers.split(",")
         replServers = self.Get("ld_repl_servers")
         replServers = replServers.split(",")
-        if set(replServers) != set(replSambaServers)|set(replUnixServers):
+        if set(replServers) != \
+            set(replSambaServers)|set(replUnixServers)|set(replMailServers):
             return ""
         replIds = self.Get("ld_repl_ids")
         replIds = replIds.split(",")
@@ -306,7 +314,8 @@ class fillVars(object, cl_base.glob_attr):
         for replServer in replServers:
             if replIds[i]!= repl_id:
                 if replServer in replSambaServers:
-                    servers_info += """syncrepl rid=%s
+                    if replServer in replMailServers:
+                        servers_info += """syncrepl rid=%s
     provider=ldap://%s
     type=refreshAndPersist
     retry="5 5 300 +"
@@ -321,12 +330,63 @@ class fillVars(object, cl_base.glob_attr):
                         self.Get("ld_services_dn"),
                         self.Get("ld_repl_dn"),
                         self.Get("ld_repl_pw"))
+                    else:
+                        servers_info += 'syncrepl rid=%s\n\
+    provider=ldap://%s\n\
+    type=refreshAndPersist\n\
+    retry="5 5 300 +"\n\
+    filter="(&(|(|(ou:dn:=Samba)(ou:dn:=Unix))(ou:dn:=Replication))\
+(!(&(ou:dn:=Replication)(ou:dn:=Mail))))"\n\
+    searchbase="%s"\n\
+    attrs="*,+"\n\
+    schemachecking=on\n\
+    bindmethod=simple\n\
+    binddn="%s"\n\
+    credentials=%s\n' %(replIds[i], 
+                        replServer,
+                        self.Get("ld_services_dn"),
+                        self.Get("ld_repl_dn"),
+                        self.Get("ld_repl_pw"))
                 elif replServer in replUnixServers:
+                    if replServer in replMailServers:
+                        servers_info += 'syncrepl rid=%s\n\
+    provider=ldap://%s\n\
+    type=refreshAndPersist\n\
+    retry="5 5 300 +"\n\
+    filter="(&(|(ou:dn:=Unix)(ou:dn:=Replication))(!(&(ou:dn:=Replication)\
+(ou:dn:=Worked))))"\n\
+    searchbase="%s"\n\
+    attrs="*,+"\n\
+    schemachecking=on\n\
+    bindmethod=simple\n\
+    binddn="%s"\n\
+    credentials=%s\n' %(replIds[i], 
+                        replServer,
+                        self.Get("ld_services_dn"),
+                        self.Get("ld_repl_dn"),
+                        self.Get("ld_repl_pw"))
+                    else:
+                        servers_info += """syncrepl rid=%s
+    provider=ldap://%s
+    type=refreshAndPersist
+    retry="5 5 300 +"
+    filter="(|(ou:dn:=Unix)(ou=Replication))"
+    searchbase="%s"
+    attrs="*,+"
+    schemachecking=on
+    bindmethod=simple
+    binddn="%s"
+    credentials=%s\n""" %(replIds[i], 
+                        replServer,
+                        self.Get("ld_services_dn"),
+                        self.Get("ld_repl_dn"),
+                        self.Get("ld_repl_pw"))
+                elif replServer in replMailServers:
                     servers_info += """syncrepl rid=%s
     provider=ldap://%s
     type=refreshAndPersist
     retry="5 5 300 +"
-    filter="(|(ou:dn:=Unix)(ou:dn:=Replication))"
+    filter="(&(ou:dn:=Replication)(ou:dn:=Mail))"
     searchbase="%s"
     attrs="*,+"
     schemachecking=on
@@ -370,7 +430,7 @@ class fillVars(object, cl_base.glob_attr):
             return netAllow
         osNetAllow = self.Get("os_net_allow")
         if osNetAllow:
-            return "%s 127." %osNetAllow
+            return "%s 127." %osNetAllow.replace(","," ")
         return "127."
 
     def get_sr_mail_net_allow_pass(self):
@@ -389,7 +449,7 @@ class fillVars(object, cl_base.glob_attr):
             return netAllow
         osNetAllow = self.Get("os_net_allow")
         if osNetAllow:
-            return "%s, 127.0.0.0/8" %osNetAllow
+            return "%s, 127.0.0.0/8" %osNetAllow.replace(",",", ")
         return "127.0.0.0/8"
 
     def get_sr_samba_net_allow(self):
@@ -404,4 +464,37 @@ class fillVars(object, cl_base.glob_attr):
         netAllow = self.Get("os_net_allow")
         if netAllow:
             return netAllow
-        return ""
\ No newline at end of file
+        return ""
+
+    def get_ld_repl_mail_dn(self):
+        """DN ветки хранения реплицируемых алиасов"""
+        return "ou=%s,%s" %(self.Get('ld_repl_mail_login'),
+                            self.Get('ld_repl_dn'))
+
+    def get_ld_repl_mail_set(self):
+        """Включена или нет репликация для сервиса Mail"""
+        replMailServers = self.Get("ld_repl_mail_servers")
+        if replMailServers:
+            replMailServers = replMailServers.split(",")
+        else:
+            return "off"
+        hostName = self.Get('os_net_hostname')
+        domain = self.Get('os_net_domain')
+        fullHostName = "%s.%s"%(hostName,domain)
+        if fullHostName in replMailServers:
+            return "on"
+        return "off"
+
+    def get_ld_repl_unix_set(self):
+        """Включена или нет репликация для сервиса Unix"""
+        replUnixServers = self.Get("ld_repl_unix_servers")
+        if replUnixServers:
+            replUnixServers = replUnixServers.split(",")
+        else:
+            return "off"
+        hostName = self.Get('os_net_hostname')
+        domain = self.Get('os_net_domain')
+        fullHostName = "%s.%s"%(hostName,domain)
+        if fullHostName in replUnixServers:
+            return "on"
+        return "off"
\ No newline at end of file
