@@ -139,6 +139,9 @@ class Data:
     # имя компьютера с настроенным сервисом Jabber
     sr_jabber_host = {}
 
+    # jabber id пользователя
+    sr_jabber_user_id = {'mode':"w"}
+
     # шифрование при получении - ''/ssl
     sr_jabber_crypt = {'mode':"w",'value':'ssl'}
 
@@ -318,7 +321,7 @@ class Data:
 
     # Calculate плюс версия калкулэйта для записи в заголовок файла
     # объединяемого с профилем
-    cl_ver = {'value':'Calculate-server 2.0.9'}
+    cl_ver = {'value':'Calculate-server 2.0.10'}
 
     #DN LDAP ветки, в котором будут находится служебные ветки
     ld_ldap_dn = {}
@@ -382,4 +385,4 @@ class Data:
     ld_repl_mail_set = {}
     #Настроен или нет сервис Mail как почтовый релей
     sr_mail_relay_set = {'mode':"w",
-                         'value':'off'}
\ No newline at end of file
+                         'value':'off'}
